@@ -31,16 +31,15 @@ class Dataset(ABC):
 
         self.path = path
 
-    def get(self, clean_cache: bool = False, debug: bool = False, **kwargs):
-
-        if clean_cache or not self.is_valid(**kwargs):
+    def get(self, clean: bool = False, debug: bool = False, **kwargs):
+        if clean or not self.is_valid():
 
             if not debug:
                 shutil.rmtree(self.path, ignore_errors=True)
                 self.path.mkdir(parents=True)
 
             # get data
-            coro = self.download(**kwargs)
+            coro = self.download()
 
             if coro is not None:
                 asyncio.run(coro)
@@ -50,15 +49,15 @@ class Dataset(ABC):
 
         return self.load(**kwargs)
 
-    def is_valid(self, **kwargs):
+    def is_valid(self):
         return (self.path / ".valid").exists()
 
     @abstractmethod
-    def download(self, **kwargs):
+    def download(self):
         pass
 
     @abstractmethod
-    def load(self, **kwargs):
+    def load(self):
         pass
 
 
